Re: [PATCH v3 0/4] Optimization batch 12: miscellaneous unthemed stuff
- From
Derrick Stolee <stolee@gmail.com>
- Date
- Jun 4, 2021, 13:11 UTC
- Message-ID
- <a5755340-c0c8-8028-7c03-3c8e7f0268d1@gmail.com>
- In-Reply-To
- <pull.962.v3.git.1622781578.gitgitgadget@gmail.com>
On 6/4/2021 12:39 AM, Elijah Newren via GitGitGadget wrote:
Show 7 quoted lines
> This series depends on en/ort-perf-batch-11 textually, but is semantically > independent of it. > > Changes since v2: > > * Made suggested minor tweaks from Stolee on Patch 1 > * Dropped patch 3, for now
With these changes, I think the code is good to go.
> * Added Stolee's Acked-by
...
Show 6 quoted lines
> 1: c4a0f6a9510c ! 1: f63ffc2a7c22 merge-ort: replace string_list_df_name_compare with faster alternative > @@ Commit message > just-one-mega: 500.3 ms ± 3.8 ms 480.1 ms ± 3.9 ms > > Signed-off-by: Elijah Newren <newren@gmail.com> > + Acked-by: Derrick Stolee <dstolee@microsoft.com>
I believe the sign-off should always be the last thing in the message. Perhaps Junio is willing to fix this without a re-roll?
Feel free to replace Acked-by with Reviewed-by.
Thanks, -Stolee